<?php

namespace apexl\Io\modules\system;

use apexl\Io\includes\Module;
use apexl\Io\modules\system\controllers\globalDataController;
use apexl\Io\modules\system\controllers\globalSystemInfo;

/**
 * Base module file, provides required methods to register things like routes and middleware.
 * Class installModule
 * @package apexl\Io\modules\install
 */
class systemModule extends Module
{

    public function __construct()
    {
        parent::__construct();
    }

    public function routes()
    {
        //Get global data
        $this->route::get('system.globaldata', '/system/globalData', globalDataController::class . ':getGlobalData');

        //get all available routes
        $this->route::get('system.routes', '/system/routes', globalSystemInfo::class . ':getRoutes');
    }
}