<?php

namespace apexl\Io\modules\authentication;

use apexl\Io\includes\Module;
use apexl\Io\modules\authentication\controllers\authenticationController;

/**
 * Base module file, provides required methods to register things like routes and middleware.
 * Class installModule
 * @package apexl\Io\modules\install
 */
class authenticationModule extends Module
{

    public function __construct()
    {
        parent::__construct();
        $this->setBaseRoute('');
    }

    public function routes()
    {
        //we have no db data so lets assume we're installing.
        $this->addRoute('GET', 'core.authenticated', '/authenticated', authenticationController::class . ':authenticated');
    }
}