<?php

namespace apexl\Io\modules\system\entities;

use apexl\Io\includes\Entity;
use apexl\Io\includes\System;
use apexl\Io\modules\system\entities\operators\cacheEntityOperator;

class cacheEntity extends Entity
{
    /** @var System */
    protected $system;

    public function __construct($cacheTable)
    {
        parent::__construct('users');
        $this->setOperator(new cacheEntityOperator($cacheTable));
        $this->system = System::getInstance();
    }
}
