<?php

namespace apexl\Io\modules\system\entities\operators;

use apexl\Io\modules\system\entities\interfaces\cacheOperatorInterface;
use apexl\Io\operators\entityDatabaseOperator;

class cacheEntityOperator extends entityDatabaseOperator {
    public function __construct($table, $primaryKey = 'id')
    {
        parent::__construct($table);
    }
}